pub struct UiModel { /* private fields */ }Expand description
Implementations
Sourceimpl UiModel
impl UiModel
pub const fn new(items: MenuItems) -> Self
pub const fn page(&self) -> Page
pub const fn notice(&self) -> Option<UiNotice>
pub const fn items(&self) -> MenuItems
Sourcepub const fn is_home(&self) -> bool
pub const fn is_home(&self) -> bool
Whether the model is showing its home page with nothing pending.
The attention lapse uses this to skip a pointless redraw.
Sourcepub fn set_notice(&mut self, notice: UiNotice)
pub fn set_notice(&mut self, notice: UiNotice)
Report a result and return to the status page.
pub fn clear_notice(&mut self)